@@ -1,5 +1,5 @@
 package Playwright;
-$Playwright::VERSION = '1.531';
+$Playwright::VERSION = '1.551';
 use strict;
 use warnings;
 
@@ -114,6 +114,7 @@ sub new ( $class, %options ) {
     my $port    = $options{port}    // Net::EmptyPort::empty_port();
     my $cdp_uri = $options{cdp_uri} // '';
     my $timeout = $options{timeout} // 30;
+    $options{maxrequest} //= '100kb';
     my $cleanup =
       ( $options{cleanup} // !( $options{port} || $options{host} ) ) ? 1 : 0;
     my $self = bless(
@@ -136,6 +137,9 @@ sub new ( $class, %options ) {
     $self->_check_and_build_spec();
     _build_classes();
 
+    # Control things about the environment we start pw in
+    $ENV{MAX_REQUEST_SIZE} = $options{maxrequest};
+
     return $self;
 }
 
@@ -384,7 +388,7 @@ Playwright - Perl client for Playwright
 
 =head1 VERSION
 
-version 1.531
+version 1.551
 
 =head1 SYNOPSIS
 
@@ -758,6 +762,7 @@ Creates a new browser and returns a handle to interact with it.
     debug (BOOL) : Print extra messages from the Playwright server process. Default: false
     timeout (INTEGER) : Seconds to wait for the playwright server to spin up and down.  Default: 30s
     cleanup (BOOL) : Whether or not to clean up the playwright server when this object goes out of scope.  Default: true
+    maxrequest (STRING) : Maximum size of bodies returned by playwright.  Refer to L<https://www.npmjs.com/package/body-parser#limit> for the format of the string.
 
 =head1 METHODS
 
@@ -838,7 +843,7 @@ George S. Baugh <teodesian@gmail.com>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Keith Carangelo reneeb Yanick Champoux
+=for stopwords Keith Carangelo reneeb Sherrard Burton Yanick Champoux
 
 =over 4
 
@@ -852,13 +857,17 @@ reneeb <info@perl-services.de>
 
 =item *
 
+Sherrard Burton <sburton@allafrica.com>
+
+=item *
+
 Yanick Champoux <yanick.champoux@iinteractive.com>
 
 =back
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2020 Troglodyne LLC
+Copyright (c) 2025 Troglodyne LLC
 
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
